window.Gleam.initSearch([{"doc":"polly","title":"polly","content":"# polly\n\n[![Package Version](https://img.shields.io/hexpm/v/polly)](https://hex.pm/packages/polly)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/polly/)\n\nPolly is a portable, polling file-system watcher, supporting the Erlang and Node.js target.\n\nWhile she may not be the fastest, she will help you in all situations where the [fs package](https://hex.pm/packages/fs) might not be suitable or supported.\n\n```sh\ngleam add polly@1\n```\n```gleam\nimport gleam/io\nimport polly\n\npub fn main() {\n  polly.new()\n  |&gt; polly.add_dir(&quot;src&quot;)\n  |&gt; polly.interval(1000)\n  |&gt; polly.watch(fn(event) {\n    case event {\n      Changed(path) -&gt; io.println(&quot;CHANGED &quot; &lt;&gt; path)\n      Created(path) -&gt; io.println(&quot;CREATED &quot; &lt;&gt; path)\n      Deleted(path) -&gt; io.println(&quot;DELETED &quot; &lt;&gt; path)\n    }\n  })\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/polly&gt;.\n","url":"index.html"},{"doc":"polly","title":"Event","content":"pub type Event {\n  Created(String)\n  Changed(String)\n  Deleted(String)\n}\n A filesystem event.\n \n Polly is careful when handing you events, and makes sure that you always get\n them in the right order, so if a dictionary with some files was created,\n you will get the dictionary event first, before any children.\nCreated(String)\n A new file or dictionary was created!\n\nChanged(String)\n A file got modified!\n\nDeleted(String)\n A file or dictionary got deleted :(\n\nSynonyms:\npolly.Event\npolly Event","url":"polly.html#Event"},{"doc":"polly","title":"FsError","content":"pub type FsError {\n  Eacces\n  Enoent\n  Enotdir\n  EUnknown(String)\n}\n Some POSIX file system errors.\n \n Only a handful of errors are handled by Polly, and everything else is collapsed into `EUnknown`.\nEacces\n\n\nEnoent\n\n\nEnotdir\n\n\nEUnknown(String)\n\n\nSynonyms:\npolly.FsError\npolly FsError","url":"polly.html#FsError"},{"doc":"polly","title":"Options","content":"pub opaque type Options\n Polly uses the builder pattern to construct a watcher.\n \n \n let options: Options = polly.new()\n     |&gt; polly.add_dir(&quot;src&quot;)\n     |&gt; polly.interval(3000)\n     |&gt; polly.max_depth(10)\n     |&gt; polly.filter(polly.default_filter)\n \n\nSynonyms:\npolly.Options\npolly Options","url":"polly.html#Options"},{"doc":"polly","title":"Watcher","content":"pub opaque type Watcher(state)\n A polling file system watcher, built from options.\n \n Watchers are automatically started, and can by stopped by calling `stop`.\n\nSynonyms:\npolly.Watcher\npolly Watcher","url":"polly.html#Watcher"},{"doc":"polly","title":"add_dir","content":"pub fn add_dir(options: Options, path: String) -&gt; Options\n Tell Polly which directory to watch. If it does not exist, `watch` will return an error.\n \n Paths are not expanded by default, so the paths reported by events and passed\n to the filter function will be prefixed with whatever you specified here.\nSynonyms:\npolly.add_dir\npolly add_dir","url":"polly.html#add_dir"},{"doc":"polly","title":"default_filter","content":"pub fn default_filter(path: String) -&gt; Bool\n The default filter function, ignoring hidden files starting with a colon `&quot;.&quot;`\nSynonyms:\npolly.default_filter\npolly default_filter","url":"polly.html#default_filter"},{"doc":"polly","title":"filter","content":"pub fn filter(\n  options: Options,\n  by filter: fn(String) -&gt; Bool,\n) -&gt; Options\n Filter files using the given predicate.\n \n Polly will ignore files and directories for which the predicate returns `False`\n completely, and any event happening for them or for a contained file of them\n will not get reported.\n \n By default, all hidden files are ignored.\nSynonyms:\npolly.filter\npolly filter","url":"polly.html#filter"},{"doc":"polly","title":"interval","content":"pub fn interval(options: Options, interval: Int) -&gt; Options\n Set the interval in-between file-system polls, in milliseconds.\n \n This options is passed through to [repeatedly.call](https://hexdocs.pm/repeatedly/repeatedly.html#call).\nSynonyms:\npolly.interval\npolly interval","url":"polly.html#interval"},{"doc":"polly","title":"max_depth","content":"pub fn max_depth(options: Options, max_depth: Int) -&gt; Options\n Limit the maximum depth that Polly will walk each directory.\n\n There is no limit by default, but setting a limit might be a good to\n better control resource usage of the watcher.\nSynonyms:\npolly.max_depth\npolly max_depth","url":"polly.html#max_depth"},{"doc":"polly","title":"new","content":"pub fn new() -&gt; Options\n Start creating a new configuration using the default options.\n \n By default, and interval of 1 second is set, and the `default_filter` is used.\nSynonyms:\npolly.new\npolly new","url":"polly.html#new"},{"doc":"polly","title":"stop","content":"pub fn stop(watcher: Watcher(a)) -&gt; Nil\n Stop this watcher.\n \n On Erlang, pending events may still be reported.\n See the documentation of [repeatedly.stop](https://hexdocs.pm/repeatedly/repeatedly.html#stop) for more information.\nSynonyms:\npolly.stop\npolly stop","url":"polly.html#stop"},{"doc":"polly","title":"watch","content":"pub fn watch(\n  options: Options,\n  with callback: fn(Event) -&gt; a,\n) -&gt; Result(Watcher(Nil), #(String, FsError))\n Tell Polly to start watching all the specified directories for changes.\n \n The callback is called synchronously after collecting all change events since\n the last run. It is adviseable to move heavier cpu-bound tasks from this\n callback into their own processes/threads.\n \n On Erlang, the callback will be called in the same process as the watcher runs in.\nSynonyms:\npolly.watch\npolly watch","url":"polly.html#watch"},{"doc":"polly","title":"watch_with","content":"pub fn watch_with(\n  options: Options,\n  from initial: a,\n  with callback: fn(a, Event) -&gt; a,\n) -&gt; Result(Watcher(a), #(String, FsError))\n Like `watch`, but similar to `list.fold` Polly will also keep some state\n around for you and pass it back on each invocation.\nSynonyms:\npolly.watch_with\npolly watch_with","url":"polly.html#watch_with"},{"doc":"polly","title":"polly","content":"","url":"polly.html"}]);